multiplicationer

package module
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2022 License: MIT Imports: 2 Imported by: 0

README

multiplicationer

A package that multiplies two values Gives the user the option to either enable or disable logging

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Multiplyer added in v0.1.3

type Multiplyer struct {
	LogAnswer bool
}

func NewMultiplyer added in v0.1.3

func NewMultiplyer(mul bool) *Multiplyer

func (*Multiplyer) Multiply added in v0.1.3

func (m *Multiplyer) Multiply(firstValue, secondValue float64) float64

Jump to